@@ -9,7 +9,7 @@ class FlowElement(object):
         if type(self)!=NullProcessor:
             self.out_objects=[NullProcessor()]
             self.out_in_objects=[NullProcessor()]
-            self.error_objects=[NullProcessor()]
+            self.error_objects=[Printer('unhandled error')]
     def compute_args(self,elem={}):
         new_largs=[x for x in self.connector_largs]
         new_kwargs=self.connector_kwargs.copy()
